==> fluxbox-1.3.5.tar.xz: fluxbox-1.3.5/nls/cs_CZ/generated-UTF-8.m <==
$ codeset=UTF-8

$set 1 #Align

1 Dole uprostřed
2 Dole vlevo
3 Dole vpravo
4 Horizontálně
5 Vlevo
6 Vlevo dole
7 Vlevo uprostřed
8 Vlevo nahoře
9 Relativně
10 Vpravo
11 Vpravo dole
12 Vpravo uprostřed
13 Vpravo nahoře
14 Nahoře uprostřed
15 Nahoře vlevo
16 Nahoře vpravo
17 Vertikálně

$set 2 #BaseDisplay

1 Ukončuji... zaznamenávám pád aplikace\n
2 Vypínám\n
3 %s:      zachycen signál %d\n

$set 3 #Common

1 Alpha
2 Automaticky skrývat
3 Zkompilováno
4 Nastavení kompilátoru
5 Kompilátor
6 Verze kompilátoru
7 Soubor init
8 Soubor s definicí kláves
10 Soubor s definicí menu
11 Soubor se stylem
12 Implicitní
13 neaktivní
14 Chyba
15 Verze Fluxboxu
16 Maximalizovat přes všechna okna
18 Viditelný

$set 4 #Configmenu

1 Antialiasované fonty
2 Automatické vyzvednutí okna
3 Vyzvednutí okna kliknutím
4 Zaměření okna kliknutím
5 Odekorovat pomíjivá okna
6 Přepínání ploch kolečkem myši
7 Zaměřit okno při změně plochy
8 Model zaměření okna
9 Zaměřit nová okna
10 Plná maximalizace
11 Dithering obrazu
12 Pohyb okna i s obsahem
13 Částečně nedbalé zaměření okna
14 Nedbalé zaměření okna
15 Prolínání ploch
16 Vynutit pseudo-průhlednost
17 Alpha menu
18 Průhlednost
19 Alpha zaměřeného okna
20 Alpha nezaměřeného okna

$set 5 #Ewmh

1 Fatal: Out of memory, can't allocate for EWMH client list

$set 6 #FbTkError

1 Warning! Height > 3200 setting Height = 3200
2 Warning! Width > 3200 setting Width = 3200
3 Warning: can't load fallback font
4 Allocation error.
5 Error creating pixmap
6 Cant create XImage
7 Failed to read
8 Warning: Failed to find valid format for alpha.
9 Warning: Failed to create alpha picture.
10 Warning: Failed to create alpha pixmap.
11 Failed to find format for screen(%d)
12 Out of memory
13 Out of memory while allocating blue buffer.
14 Out of memory while allocating green buffer.
15 Out of memory while allocating red buffer.
16 Failed to read theme item
17 unsupported visual
18 Setting default value

$set 7 #Fluxbox

1 rc filename is invalid!
2 Failed to load groupfile
3 Failed to load database
4 Retrying with
5 Warning! Could not find screen to map window on!
6 Can't create %s directory
7 Couldn't find screens to manage.\nMake sure you don't have another window manager running.
8 Error parsing regular expression
9 Fatal! There can only one instance of fluxbox class.
10 Can not connect to X server.\nMake sure you started X before you start Fluxbox.
11 Warning: X server does not support locale
12 Warning: cannot set locale modifiers

$set 8 #Gnome

1 Fatal: Out of memory, can't allocate for GNOME client list

$set 9 #Keys

1 Keys: Error on line
2 Keys: Failed to merge keytree!
3 Keys: Invalid key/modifier on line

$set 10 #Menu

1 Konfigurace
2 Implicitní menu Fluxboxu
3 Ukončit
4 Minimalizované
5 Vrstva...
6 On Head...
7 Umístění
8 Znovu načíst konfiguraci
9 Restart

$set 11 #Remember

1 Decorace
2 Rozměr
3 Skok na plochu
4 Vrstva
5 Zapamatovat...
6 Pozice
7 Uložit při zavření
8 Zarolování
9 Přišpendlení
10 Neznámé klávesy aplikace
11 Plocha
12 Hlavička

$set 12 #Screen

1 BScreen::BScreen: an error occured while querying the X server.\n	another window manager already running on display
2 W: %4d x H: %4d
3 BScreen::BScreen: managing screen %d using visual 0x%lx, depth %d\n
4 W: %04d x H: %04d

$set 13 #Slit

1 Klientské aplikace
2 Rolovat dolů
3 Rolovat nahoru
4 Umístění Slitu
5 Vrstva Slitu
6 Slit on Head
7 Umístění Slitu
8 Slit
9 Uložit SlitList

$set 14 #Toolbar

1 Upravit název aktuální plochy
2 Zobrazovat...
3 Všechna okna
4 Zminimalizovaná
5 Žádná
6 Aktuální plocha
7 Zminimalizované na aktuální ploše
8 Vrstva nástrojové lišty
9 Toolbar on Head
10 Umístění nástrojové lišty
11 Nástrojová lišta
12 Šířka (% šířky obrazovky)
13 Hodiny: 24h
14 Hodiny: 12h
15 Upravit formát hodin
16 Zobrazit obrázky

$set 15 #Window

1 Beze jména

$set 16 #Windowmenu

1 Zavřít
2 Minimalizovat
3 Vrstva
4 Na pozadí
5 Maximalizovat
6 Do popředí
7 Poslat na ...
8 Zarolovat
9 Přišpendlit na všechny plochy
10 Zabít

$set 17 #Workspace

1 Plocha %d
2 Seznam ploch
3 Nová plocha
4 Odstranit poslední

$set 18 #fbsetroot

1 error: must specify one of: -solid, -mod, -gradient\n
2 Couldn't create pixmap atoms, giving up!
3 -display <string>        display connection\n\
-mod <x> <y>             modula pattern\n\
-foreground, -fg <color> modula foreground color\n\
-background, -bg <color> modula background color\n\n\
-gradient <texture>      gradient texture\n\
-from <color>            gradient start color\n\
-to <color>              gradient end color\n\n\
-solid <color>           solid color\n\n\
-help                    print this help text and exit\n

$set 19 #main

1 chyba: '-display' vyžaduje argument
2 Bad Alloc
3 Bad cast
4 Out of range
5 Runtime error
6 Standard Exception
7 Neznámá chyba
8 chyba: '-log' vyžaduje argument
9 Logovací soubor
10 Loguji do
11 chyba: '-rc' vyžaduje argument
13 Fluxbox %s: (c) %s Henrik Kinnunen\n\n\
-display <string>\t\tpouzžije propojení s displejem <string>.\n\
-rc <string>\t\t\tpouzije alternativní soubor zdrojů (resource file).\n\
-version\t\t\tzobrazi verzi a skonci.\n\
-info\t\t\t\tzobrazi nektere zajimave informace.\n\
-log <filename>\t\t\tlogovat výstup do souboru <filename>.\n\
-help\t\t\t\tzobrazí tuto nápovědu a skončí.\n\n
14 varování: nemohu nastavit proměnnou prostředí 'DISPLAY'

$set 20

1 Nad dokem
2 Naspod
3 Plocha
4 Dok
5 Normální
6 Navrchu

==> fluxbox-1.3.7.tar.xz: fluxbox-1.3.7/nls/cs_CZ/generated-UTF-8.m <==
$ codeset=UTF-8

$set 1 #Align

1 Dole uprostřed
2 Dole vlevo
3 Dole vpravo
4 Horizontálně
5 Vlevo
6 Vlevo dole
7 Vlevo uprostřed
8 Vlevo nahoře
9 Relativně
10 Vpravo
11 Vpravo dole
12 Vpravo uprostřed
13 Vpravo nahoře
14 Nahoře uprostřed
15 Nahoře vlevo
16 Nahoře vpravo
17 Vertikálně

$set 2 #BaseDisplay

1 Ukončuji... zaznamenávám pád aplikace\n
2 Vypínám\n
3 %s:      zachycen signál %d\n

$set 3 #Common

1 Alpha
2 Automaticky skrývat
3 Zkompilováno
4 Nastavení kompilátoru
5 Kompilátor
6 Verze kompilátoru
7 Soubor init
8 Soubor s definicí kláves
10 Soubor s definicí menu
11 Soubor se stylem
12 Implicitní
13 neaktivní
14 Chyba
15 Verze Fluxboxu
16 Maximalizovat přes všechna okna
18 Viditelný

$set 4 #Configmenu

1 Antialiasované fonty
2 Automatické vyzvednutí okna
3 Vyzvednutí okna kliknutím
4 Zaměření okna kliknutím
5 Odekorovat pomíjivá okna
6 Přepínání ploch kolečkem myši
7 Zaměřit okno při změně plochy
8 Model zaměření okna
9 Zaměřit nová okna
10 Plná maximalizace
11 Dithering obrazu
12 Pohyb okna i s obsahem
13 Částečně nedbalé zaměření okna
14 Nedbalé zaměření okna
15 Prolínání ploch
16 Vynutit pseudo-průhlednost
17 Alpha menu
18 Průhlednost
19 Alpha zaměřeného okna
20 Alpha nezaměřeného okna

$set 5 #Ewmh

1 Fatal: Out of memory, can't allocate for EWMH client list

$set 6 #FbTkError

1 Warning! Height > 3200 setting Height = 3200
2 Warning! Width > 3200 setting Width = 3200
3 Warning: can't load fallback font
4 Allocation error.
5 Error creating pixmap
6 Cant create XImage
7 Failed to read
8 Warning: Failed to find valid format for alpha.
9 Warning: Failed to create alpha picture.
10 Warning: Failed to create alpha pixmap.
11 Failed to find format for screen(%d)
12 Out of memory
13 Out of memory while allocating blue buffer.
14 Out of memory while allocating green buffer.
15 Out of memory while allocating red buffer.
16 Failed to read theme item
17 unsupported visual
18 Setting default value

$set 7 #Fluxbox

1 rc filename is invalid!
2 Failed to load groupfile
3 Failed to load database
4 Retrying with
5 Warning! Could not find screen to map window on!
6 Can't create %s directory
7 Couldn't find screens to manage.\nMake sure you don't have another window manager running.
8 Error parsing regular expression
9 Fatal! There can only one instance of fluxbox class.
10 Can not connect to X server.\nMake sure you started X before you start Fluxbox.
11 Warning: X server does not support locale
12 Warning: cannot set locale modifiers

$set 8 #Gnome

1 Fatal: Out of memory, can't allocate for GNOME client list

$set 9 #Keys

1 Keys: Error on line
2 Keys: Failed to merge keytree!
3 Keys: Invalid key/modifier on line

$set 10 #Menu

1 Konfigurace
2 Implicitní menu Fluxboxu
3 Ukončit
4 Minimalizované
5 Vrstva...
6 On Head...
7 Umístění
8 Znovu načíst konfiguraci
9 Restart

$set 11 #Remember

1 Decorace
2 Rozměr
3 Skok na plochu
4 Vrstva
5 Zapamatovat...
6 Pozice
7 Uložit při zavření
8 Zarolování
9 Přišpendlení
10 Neznámé klávesy aplikace
11 Plocha
12 Hlavička

$set 12 #Screen

1 BScreen::BScreen: an error occured while querying the X server.\n	another window manager already running on display
2 W: %4d x H: %4d
3 BScreen::BScreen: managing screen %d using visual 0x%lx, depth %d\n
4 W: %04d x H: %04d

$set 13 #Slit

1 Klientské aplikace
2 Rolovat dolů
3 Rolovat nahoru
4 Umístění Slitu
5 Vrstva Slitu
6 Slit on Head
7 Umístění Slitu
8 Slit
9 Uložit SlitList

$set 14 #Toolbar

1 Upravit název aktuální plochy
2 Zobrazovat...
3 Všechna okna
4 Zminimalizovaná
5 Žádná
6 Aktuální plocha
7 Zminimalizované na aktuální ploše
8 Vrstva nástrojové lišty
9 Toolbar on Head
10 Umístění nástrojové lišty
11 Nástrojová lišta
12 Šířka (% šířky obrazovky)
13 Hodiny: 24h
14 Hodiny: 12h
15 Upravit formát hodin
16 Zobrazit obrázky

$set 15 #Window

1 Beze jména

$set 16 #Windowmenu

1 Zavřít
2 Minimalizovat
3 Vrstva
4 Na pozadí
5 Maximalizovat
6 Do popředí
7 Poslat na ...
8 Zarolovat
9 Přišpendlit na všechny plochy
10 Zabít

$set 17 #Workspace

1 Plocha %d
2 Seznam ploch
3 Nová plocha
4 Odstranit poslední

$set 18 #fbsetroot

1 error: must specify one of: -solid, -mod, -gradient\n
2 Couldn't create pixmap atoms, giving up!
3 -display <string>        display connection\n\
-mod <x> <y>             modula pattern\n\
-foreground, -fg <color> modula foreground color\n\
-background, -bg <color> modula background color\n\n\
-gradient <texture>      gradient texture\n\
-from <color>            gradient start color\n\
-to <color>              gradient end color\n\n\
-solid <color>           solid color\n\n\
-help                    print this help text and exit\n

$set 19 #main

1 chyba: '-display' vyžaduje argument
2 Bad Alloc
3 Bad cast
4 Out of range
5 Runtime error
6 Standard Exception
7 Neznámá chyba
8 chyba: '-log' vyžaduje argument
9 Logovací soubor
10 Loguji do
11 chyba: '-rc' vyžaduje argument
13 Fluxbox %s: (c) %s Fluxbox Team\n\n\
-display <string>\t\tpouzžije propojení s displejem <string>.\n\
-screen <all|int,int,int>\trun on specified screens only.\n\
-no-slit\t\t\tdo not provide a slit\n\
-no-toolbar\t\tdo not provide a toolbar\n\
-rc <string>\t\t\tpouzije alternativní soubor zdrojů (resource file).\n\
-version\t\t\tzobrazi verzi a skonci.\n\
-info\t\t\t\tzobrazi nektere zajimave informace.\n\
-list-commands\t\t\tlist all valid key commands.\n\
-sync\t\t\t\tsynchronize with X server for debugging.\n\
-log <filename>\t\t\tlogovat výstup do souboru <filename>.\n\
-help\t\t\t\tzobrazí tuto nápovědu a skončí.\n\n
14 varování: nemohu nastavit proměnnou prostředí 'DISPLAY'

$set 20

1 Nad dokem
2 Naspod
3 Plocha
4 Dok
5 Normální
6 Navrchu
